@@ -59,6 +59,9 @@ static int handler(void* setting, const char* section, const char* name, const c
         config->threshold_roll = deg_to_rad(atoi(value));
     } else if (MATCH("control", "threshold_pitch")) {
         config->threshold_pitch = deg_to_rad(atoi(value));
+    } else if (MATCH("control", "orientation")) {
+        config->orientation = atoi(value);
+        if (config->orientation < -1 || config->orientation > 1) config->orientation = 0;
     } else if (MATCH("control", "deadzone")) {
         config->deadzone = atof(value);
     } else if (MATCH("control", "profile")) {
@@ -244,8 +247,9 @@ int main(int argc, char **argv)
     acc = sqrtf(((long)ax)*ax + ((long)ay)*ay + ((long)az)*az);  //Use long to avoid overflow when squaring ~1000 to get vector length!
 
     if (config.offset_pitch > 15 ) { // deg_to_rad( 900 ) = 15.7--A calibration has been requested. Wait for it...
-      if (time(0)-4 > config.freshness){
-        current.pitch = asinf(ay / acc);
+      if (time(0)-2 > config.freshness){
+        if (config.orientation) current.pitch = -asinf(ax / acc) * -config.orientation;
+        else current.pitch = asinf(ay / acc);
         char temp[300];
         sprintf(temp, "sed -i 's/\\(offset_pitch *= *\\)[0-9]*\\(.*\\)/\\1%0.0f\\2/' /home/user/.accelemymote/main.cfg",rad_to_deg(-current.pitch));
 	system(temp);
@@ -256,8 +260,11 @@ int main(int argc, char **argv)
       continue; // skip events while waiting for calibration 
     }
 
-    current.pitch = asinf(ay / acc)+config.offset_pitch;
+    current.pitch = asinf(ay / acc);
     current.roll = -asinf(ax / acc);
+    if (config.orientation) current.roll += config.offset_pitch * -config.orientation;
+    else current.pitch += config.offset_pitch;
+
     if (debug && !(frames%24)) 
       printf("Frame: acceleration(%d,%d,%d)=%.0f. Tilt (%0.2f,%0.2f) with offset %0.2f included.\n",ax,ay,az,acc,current.pitch, current.roll, config.offset_pitch);
 
@@ -298,12 +305,14 @@ int main(int argc, char **argv)
     // Send significantly changed control states to UINPUT
     if ((current.roll-previous.roll) * (current.roll-previous.roll) > config.threshold_roll*config.threshold_roll) // abs()
     {
-      do_uinput(uinput_fd, ABS_X, (current.roll/config.max_roll) * (MAX_AXIS/2), EV_ABS);
+      if (config.orientation) do_uinput(uinput_fd, ABS_Y, (current.roll/config.max_roll) * (MAX_AXIS/2) * config.orientation, EV_ABS);
+      else do_uinput(uinput_fd, ABS_X, (current.roll/config.max_roll) * (MAX_AXIS/2), EV_ABS);
       previous.roll = current.roll;
     }
     if ((current.pitch-previous.pitch) * (current.pitch-previous.pitch) > config.threshold_pitch*config.threshold_pitch) // abs()
     {
-      do_uinput(uinput_fd, ABS_Y, ((current.pitch/config.max_pitch) * (MAX_AXIS/2) * config.flip_pitch), EV_ABS);
+      if (config.orientation) do_uinput(uinput_fd, ABS_X, (current.pitch/config.max_pitch) * (MAX_AXIS/2) * config.orientation, EV_ABS);
+      else do_uinput(uinput_fd, ABS_Y, ((current.pitch/config.max_pitch) * (MAX_AXIS/2) * config.flip_pitch), EV_ABS);
       previous.pitch = current.pitch;
     }
 
